@@ -1,2 +1,2 @@
-from .utils import get_subject_visit
+from .utils import get_related_visit
 from .visit_tracking_modelform_mixin import VisitTrackingModelFormMixin
