@@ -1,9 +1,9 @@
 from django.contrib import admin
 from django.test import TestCase
 from django.test.client import RequestFactory
+from django_audit_fields.admin import ModelAdminAuditFieldsMixin, audit_fields
 from edc_appointment.models import Appointment
 from edc_facility.import_holidays import import_holidays
-from edc_model_admin import ModelAdminAuditFieldsMixin, audit_fields
 from edc_reference import site_reference_configs
 from edc_visit_schedule.fieldsets import visit_schedule_fields
 from edc_visit_schedule.site_visit_schedules import site_visit_schedules
@@ -52,9 +52,9 @@ class TestModelAdmin(TestCase):
             visit_models={"edc_appointment.appointment": "edc_visit_tracking.subjectvisit"}
         )
 
-    def test_visit_model_attr(self):
+    def test_related_visit_model_attr(self):
         modeladmin = edc_visit_tracking_admin._registry.get(CrfOne)
-        self.assertTrue("subject_visit", modeladmin.visit_model_attr)
+        self.assertTrue("subject_visit", modeladmin.related_visit_model_attr())
 
     def test_adds_to_list_display(self):
         factory = RequestFactory()
@@ -68,19 +68,19 @@ class TestModelAdmin(TestCase):
         request = factory.get("/")
         modeladmin = edc_visit_tracking_admin._registry.get(CrfOne)
         self.assertIn(
-            f"{modeladmin.visit_model_attr}__report_datetime",
+            f"{modeladmin.related_visit_model_attr()}__report_datetime",
             modeladmin.get_list_filter(request),
         )
         self.assertIn(
-            f"{modeladmin.visit_model_attr}__reason",
+            f"{modeladmin.related_visit_model_attr()}__reason",
             modeladmin.get_list_filter(request),
         )
         self.assertIn(
-            f"{modeladmin.visit_model_attr}__visit_code",
+            f"{modeladmin.related_visit_model_attr()}__visit_code",
             modeladmin.get_list_filter(request),
         )
         self.assertIn(
-            f"{modeladmin.visit_model_attr}__visit_code_sequence",
+            f"{modeladmin.related_visit_model_attr()}__visit_code_sequence",
             modeladmin.get_list_filter(request),
         )
 
@@ -89,7 +89,7 @@ class TestModelAdmin(TestCase):
         request = factory.get("/")
         modeladmin = edc_visit_tracking_admin._registry.get(CrfOne)
         self.assertIn(
-            f"{modeladmin.visit_model_attr}__appointment__subject_identifier",
+            f"{modeladmin.related_visit_model_attr()}__appointment__subject_identifier",
             modeladmin.get_search_fields(request),
         )
 
@@ -102,7 +102,7 @@ class TestModelAdmin(TestCase):
         modeladmin = edc_visit_tracking_admin._registry.get(CrfOne)
 
         class Fld:
-            name = modeladmin.visit_model_attr
+            name = modeladmin.related_visit_model_attr()
 
             def formfield(self, **kwargs):
                 return kwargs
@@ -128,7 +128,7 @@ class TestModelAdmin(TestCase):
         CrfOne.objects.create(subject_visit=subject_visit)
 
         class Fld:
-            name = modeladmin.visit_model_attr
+            name = modeladmin.related_visit_model_attr()
 
             def formfield(self, **kwargs):
                 return kwargs
